questions = [
    {
        "type": "input",
        "name": "access_id",
        "message": "AWS access id"
    },
    {
        "type": "input",
        "name": "secret_key",
        "message": "AWS secret key"
    }
]
