class PyloneApi():
    def __init__(self, config, global_config):
        self.cfg = config
        self.gcf = global_config

    def check_for_update(self, stage):
        pass

    def update(self, stage):
        pass

    def create(self):
        pass

    def remove(self):
        pass